==> apache-camel-4.4.2-src.zip: apache-camel-4.4.2/components/camel-aws/camel-aws2-s3/src/test/java/org/apache/camel/component/aws2/s3/integration/S3StreamUploadTimeoutIT.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.aws2.s3.integration;

import java.util.List;
import java.util.concurrent.TimeUnit;

import org.apache.camel.EndpointInject;
import org.apache.camel.Exchange;
import org.apache.camel.ProducerTemplate;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.aws2.s3.AWS2S3Constants;
import org.apache.camel.component.aws2.s3.AWS2S3Operations;
import org.apache.camel.component.mock.MockEndpoint;
import org.awaitility.Awaitility;
import org.junit.jupiter.api.Test;
import software.amazon.awssdk.services.s3.model.S3Object;

import static org.junit.jupiter.api.Assertions.assertEquals;

public class S3StreamUploadTimeoutIT extends Aws2S3Base {

    @EndpointInject
    private ProducerTemplate template;

    @EndpointInject("mock:result")
    private MockEndpoint result;

    @Test
    public void sendIn() throws Exception {

        for (int i = 1; i <= 2; i++) {
            int count = i * 23;

            result.expectedMessageCount(count);

            for (int j = 0; j < 23; j++) {
                template.sendBody("direct:stream1", "Andrea\n");
            }

            Awaitility.await().atMost(11, TimeUnit.SECONDS)
                    .untilAsserted(() -> MockEndpoint.assertIsSatisfied(context));

            Awaitility.await().atMost(11, TimeUnit.SECONDS)
                    .untilAsserted(() -> {
                        Exchange ex = template.request("direct:listObjects", this::process);

                        List<S3Object> resp = ex.getMessage().getBody(List.class);
                        assertEquals(1, resp.size());
                    });
        }
    }

    private void process(Exchange exchange) {
        exchange.getIn().setHeader(AWS2S3Constants.S3_OPERATION, AWS2S3Operations.listObjects);
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            @Override
            public void configure() {
                String awsEndpoint1
                        = "aws2-s3://mycamel-1?autoCreateBucket=true&streamingUploadMode=true&keyName=fileTest.txt&batchMessageNumber=25&namingStrategy=random&streamingUploadTimeout=10000";

                from("direct:stream1").to(awsEndpoint1).to("mock:result");

                String awsEndpoint = "aws2-s3://mycamel-1?autoCreateBucket=true";

                from("direct:listObjects").to(awsEndpoint);
            }
        };
    }
}

==> apache-camel-4.14.5-src.zip: apache-camel-4.14.5/components/camel-aws/camel-aws2-s3/src/test/java/org/apache/camel/component/aws2/s3/integration/S3StreamUploadTimeoutIT.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.aws2.s3.integration;

import java.util.List;
import java.util.concurrent.TimeUnit;

import org.apache.camel.EndpointInject;
import org.apache.camel.Exchange;
import org.apache.camel.ProducerTemplate;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.aws2.s3.AWS2S3Constants;
import org.apache.camel.component.aws2.s3.AWS2S3Operations;
import org.apache.camel.component.mock.MockEndpoint;
import org.awaitility.Awaitility;
import org.junit.jupiter.api.Test;
import software.amazon.awssdk.services.s3.model.S3Object;

import static org.junit.jupiter.api.Assertions.assertEquals;

public class S3StreamUploadTimeoutIT extends Aws2S3Base {

    @EndpointInject
    private ProducerTemplate template;

    @EndpointInject("mock:result")
    private MockEndpoint result;

    @Test
    public void sendIn() throws Exception {

        for (int i = 1; i <= 2; i++) {
            int count = i * 23;

            result.expectedMessageCount(count);

            for (int j = 0; j < 23; j++) {
                template.sendBody("direct:stream1", "Andrea\n");
            }

            Awaitility.await().atMost(11, TimeUnit.SECONDS)
                    .untilAsserted(() -> MockEndpoint.assertIsSatisfied(context));

            Awaitility.await().atMost(11, TimeUnit.SECONDS)
                    .untilAsserted(() -> {
                        Exchange ex = template.request("direct:listObjects", this::process);

                        List<S3Object> resp = ex.getMessage().getBody(List.class);
                        assertEquals(1, resp.size());
                    });
        }
    }

    private void process(Exchange exchange) {
        exchange.getIn().setHeader(AWS2S3Constants.S3_OPERATION, AWS2S3Operations.listObjects);
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            @Override
            public void configure() {
                String awsEndpoint1
                        = String.format(
                                "aws2-s3://%s?autoCreateBucket=true&streamingUploadMode=true&keyName=fileTest.txt&batchMessageNumber=25&namingStrategy=random&streamingUploadTimeout=10000",
                                name.get());

                from("direct:stream1").to(awsEndpoint1).to("mock:result");

                String awsEndpoint = String.format("aws2-s3://%s?autoCreateBucket=true",
                        name.get());

                from("direct:listObjects").to(awsEndpoint);
            }
        };
    }
}
